import { Component, OnInit, Input, Output, EventEmitter } from '@angular/core';
import { CommonCompModule } from '../../../../services/common.modules';
import { NzSelectModule } from 'ng-zorro-antd/select';
import { ReactiveFormsModule } from '@angular/forms';
import { NzRadioModule } from 'ng-zorro-antd/radio';
import { NzMessageService } from 'ng-zorro-antd/message';
import { NzGridModule } from 'ng-zorro-antd/grid';
import { NzCheckboxModule } from 'ng-zorro-antd/checkbox';
import { NzTableModule } from 'ng-zorro-antd/table';
import { NzUploadChangeParam } from 'ng-zorro-antd/upload';
import { NzUploadModule } from 'ng-zorro-antd/upload';
import {
  FormControl,
  FormGroup,
  NonNullableFormBuilder,
  Validators,
} from '@angular/forms';
interface course {
  date: Date | any;
  wordage: number | any;
  num: number | any;
  sumNum: number | any;
  accolade: string;
}
@Component({
  selector: 'app-attachment',
  imports: [
    CommonCompModule,
    ReactiveFormsModule,
    NzSelectModule,
    NzRadioModule,
    NzGridModule,
    NzCheckboxModule,
    NzTableModule,
    NzUploadModule
  ],
  standalone: true,
  templateUrl: './attachment.component.html',
  styleUrls: ['./attachment.component.scss'],
})
export class AttachmentComponent implements OnInit {
  @Input('editFrom') editFrom: any;
  @Input('maxWidth') maxWidth: number = 0;
  @Output() next: EventEmitter<any> = new EventEmitter<any>();
  @Output() save: EventEmitter<any> = new EventEmitter<any>();
  validateForm: FormGroup<{
    textbookTypes: FormControl<Array<string> | any>; //教材电子版
    textbookFiles: FormControl<Array<string> | any>;//上传教材文件
    links: FormControl<string> //教材数字内容链接地址、账号
  }> = this.fb.group({
    textbookTypes: ['', [Validators.required]],
    textbookFiles: ['', [Validators.required]],
    links: ['', [Validators.required]],
  });
  checkOptionsOne = [
    { label: '纸质教材', value: '纸质教材' },
    { label: '电子教材 / 资源', value: '电子教材 / 资源' },
  ];
  //申报教材建设历程
  courses: Array<course> = [
    {
      date: '', //出版时间
      wordage: '', //字数
      num: '', //重印次数
      sumNum: '', //本版总印数
      accolade: '', //获奖励情况
    },
  ];
  constructor(
    private fb: NonNullableFormBuilder,
    private msg: NzMessageService
  ) {}
  ngOnInit() {}
  submitForm(event?: string): void {
    console.log(this.validateForm.value);
    if (this.validateForm.valid) {
      console.log(this.validateForm.value);
    } else {
      Object.values(this.validateForm.controls).forEach((control) => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
      this.msg.warning('请填写完整信息');
    }
    if (event == 'next') {
      this.next.emit();
    }
  }
  changeCode() {}
  getCode(e: any) {}
  //添加作者信息
  onPush(idx: number) {
    this.courses.splice(idx + 1, 0, {
      date: '',
      wordage: '',
      num: '',
      sumNum: '',
      accolade: '',
    });
  }
  //删除作者信息
  onDel(idx: number) {
    this.courses.splice(idx, 1);
  }
  handleChange(info: NzUploadChangeParam): void {
    if (info.file.status !== 'uploading') {
      console.log(info.file, info.fileList);
    }
    if (info.file.status === 'done') {
      this.msg.success(`${info.file.name} file uploaded successfully`);
    } else if (info.file.status === 'error') {
      this.msg.error(`${info.file.name} file upload failed.`);
    }
  }
}
